@@ -74,6 +74,19 @@ class SnapshotPolicyFunctions(object):
             resource_type=SNAPSHOT_POLICY,
             resource_type_id=snapshot_policy_name)
 
+    def get_snapshot_policy_storage_group_list(self, snapshot_policy_name):
+        """Get list of storage groups associated to specified snapshot policy.
+
+        :param snapshot_policy_name: name of the snapshot policy -- str
+        :returns: snapshot policy details -- list
+        """
+        response = self.get_resource(
+            category=REPLICATION,
+            resource_level=SYMMETRIX, resource_level_id=self.array_id,
+            resource_type=SNAPSHOT_POLICY,
+            resource_type_id=snapshot_policy_name, object_type=STORAGEGROUP)
+        return response.get('name', list()) if response else list()
+
     def create_snapshot_policy(
             self, snapshot_policy_name, interval, cloud_retention_days=None,
             cloud_provider_name=None, local_snapshot_policy_secure=False,
@@ -102,8 +115,10 @@ class SnapshotPolicyFunctions(object):
         :param offset_mins: Defines when, within the interval the snapshots
                             will be taken for a specified Snapshot Policy.
                             The offset must be less than the interval of
-                            the Snapshot Policy. The format must be in minutes
-                            -- int
+                            the Snapshot Policy. For daily snapshots the offset
+                            is the number of minutes after midnight UTC,
+                            for weekly the offset is from midnight UTC on
+                            the Sunday. The format must be in minutes -- int
         :param compliance_count_warning: The Number of snapshots which are
                                          not failed or bad when compliance
                                          changes to warning. -- int
