@@ -1,4 +1,4 @@
-# Copyright (c) 2019 Dell Inc. or its subsidiaries.
+# Copyright (c) 2020 Dell Inc. or its subsidiaries.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,12 +20,12 @@ from PyU4V.utils import decorators
 LOG = logging.getLogger(__name__)
 
 
-@decorators.deprecation_notice('utils', 91, 93)
+@decorators.deprecation_notice('utils', 9.1, 10.0)
 def choose_from_list(query_category, query_list):
     """Choose an item from a list.
 
     DEPRECATION NOTICE: utils.console.choose_from_list() will be deprecated
-    in PyU4V version 9.3. For further information please consult PyU4V 9.1
+    in PyU4V version 10.0. For further information please consult PyU4V 9.1
     release notes.
 
     :param query_category: query category e.g. snapshot -- str
